@@ -21,17 +21,22 @@
 #include <xoshiro.h>
 #include <pcg_random.hpp>
 #include <threefry.h>
+#include <convert_seed.h>
+#include <R_randgen.h>
 
 namespace {
-dqrng::rng64_t rng = dqrng::generator();
+dqrng::rng64_t init() {
+  Rcpp::IntegerVector seed(2, dqrng::R_random_int);
+  return dqrng::generator(dqrng::convert_seed<uint64_t>(seed));
+}
+dqrng::rng64_t rng = init();
 }
 
 // [[Rcpp::interfaces(r, cpp)]]
 
 // [[Rcpp::export(rng = false)]]
-void dqset_seed(const uint32_t seed) {
-  uint64_t seed2  = 1664525 * seed + 1013904223;
-  uint64_t _seed = seed | (seed2 << 32);
+void dqset_seed(Rcpp::IntegerVector seed) {
+  uint64_t _seed = dqrng::convert_seed<uint64_t>(seed);
   rng->seed(_seed);
 }
 
@@ -44,8 +49,6 @@ void dqRNGkind(std::string kind, const std::string& normal_kind = "ignored") {
   uint64_t seed = rng->operator()();
   if (kind == "default") {
     rng =  dqrng::generator(seed);
-  } else if (kind == "mersenne-twister") {
-    rng =  dqrng::generator<std::mt19937_64>(seed);
   } else if (kind == "xoroshiro128+") {
     rng =  dqrng::generator<dqrng::xoroshiro128plus>(seed);
   } else if (kind == "xoshiro256+") {
