@@ -3,7 +3,7 @@
 #include <dqrng.h>
 
 // [[Rcpp::export]]
-bool consecutive_calls(int seed) {
+bool consecutive_calls(Rcpp::IntegerVector seed) {
   dqrng::dqset_seed(seed);
   Rcpp::NumericVector u1 = dqrng::dqrunif(10);
   Rcpp::NumericVector u2 = dqrng::dqrunif(10);
@@ -11,15 +11,16 @@ bool consecutive_calls(int seed) {
 }
 
 // [[Rcpp::export]]
-bool seed_uniform(int seed) {
+bool seed_uniform(Rcpp::IntegerVector seed) {
   dqrng::dqset_seed(seed);
   Rcpp::NumericVector u1 = dqrng::dqrunif(10);
   dqrng::dqset_seed(seed);
   Rcpp::NumericVector u2 = dqrng::dqrunif(10);
   return Rcpp::is_true(Rcpp::all(u1 == u2));
 }
+
 // [[Rcpp::export]]
-bool seed_normal(int seed) {
+bool seed_normal(Rcpp::IntegerVector seed) {
   dqrng::dqset_seed(seed);
   Rcpp::NumericVector n1 = dqrng::dqrnorm(10);
   dqrng::dqset_seed(seed);
@@ -28,7 +29,7 @@ bool seed_normal(int seed) {
 }
 
 // [[Rcpp::export]]
-bool seed_exponential(int seed) {
+bool seed_exponential(Rcpp::IntegerVector seed) {
   dqrng::dqset_seed(seed);
   Rcpp::NumericVector e1 = dqrng::dqrexp(10);
   dqrng::dqset_seed(seed);
