@@ -11,15 +11,6 @@ test_that("Default generator: setting seed produces identical uniformly distribu
   expect_equal(u1, u2)
 })
 
-test_that("Mersenne-Twister: setting seed produces identical uniformly distributed numbers", {
-  dqRNGkind("Mersenne-Twister")
-  dqset.seed(seed)
-  u1 <- dqrunif(10)
-  dqset.seed(seed)
-  u2 <- dqrunif(10)
-  expect_equal(u1, u2)
-})
-
 test_that("PCG64: setting seed produces identical uniformly distributed numbers", {
   dqRNGkind("pcg64")
   dqset.seed(seed)
